@@ -5,7 +5,7 @@ use Apache::Constants qw(OK DECLINED);
 use Apache::SIG ();
 
 @Apache::EXPORT_OK = qw(exit warn);
-$Apache::VERSION = "1.24";
+$Apache::VERSION = "1.25";
 
 *import = \&Exporter::import;
 
@@ -395,6 +395,10 @@ headers.  This can be used to initialize a perl hash, or one could use
 the $r->header_in() method (described below) to retrieve a specific
 header value directly.
 
+Will return a I<HASH> reference blessed into the I<Apache::Table>
+class when called in a scalar context with no "key" argument. This
+requires I<Apache::Table>.
+
 =item $r->header_in( $header_name, [$value] )
 
 Return the value of a client header.  Can be used like this:
@@ -554,6 +558,10 @@ C<PerlSetVar> directive.
 
    my $val = $r->dir_config('Key');
 
+Will return a I<HASH> reference blessed into the
+I<Apache::Table> class when called in a scalar context with no
+"key" argument. See I<Apache::Table>.
+
 =item $r->requires
 
 Returns an array reference of hash references, containing information
@@ -700,6 +708,10 @@ writing handlers in mod_perl you can use Perl variables for this.
    $r->notes("MY_HANDLER", OK);
    $val = $r->notes("MY_HANDLER");
 
+Will return a I<HASH> reference blessed into the I<Apache::Table>
+class when called in a scalar context with no "key" argument. This
+requires I<Apache::Table>.
+
 =item $r->subprocess_env( $key, [$value] )
 
 Return the value of a named entry in the Apache C<subprocess_env>
@@ -720,6 +732,10 @@ you can then write in your .shtml document:
    Sorry
    <!--#endif -->
 
+Will return a I<HASH> reference blessed into the I<Apache::Table>
+class when called in a scalar context with no "key" argument. This
+requires I<Apache::Table>.
+
 =item $r->content_type( [$newval] )
 
 Get or set the content type being sent to the client.  Content types
@@ -761,6 +777,10 @@ headers.  This can be used to initialize a perl hash, or one could use
 the $r->header_out() method (described below) to retrieve or set a specific
 header value directly.
 
+Will return a I<HASH> reference blessed into the I<Apache::Table>
+class when called in a scalar context with no "key" argument. This
+requires I<Apache::Table>.
+
 =item $r->header_out( $header, $value )
 
 Change the value of a response header, or create a new one.  You
@@ -781,6 +801,10 @@ The difference between headers_out and err_headers_out is that the
 latter are printed even on error, and persist across internal redirects
 (so the headers printed for ErrorDocument handlers will have them).
 
+Will return a I<HASH> reference blessed into the I<Apache::Table>
+class when called in a scalar context with no "key" argument. This
+requires I<Apache::Table>.
+
 =item $r->err_header_out( $header, [$value] )
 
 Change the value of an error response header, or create a new one.
