@@ -1,11 +1,16 @@
 package Apache::Status;
 use strict;
 
-$Apache::Status::VERSION = (qw$Revision: 1.21 $)[1];
+$Apache::Status::VERSION = (qw$Revision: 1.11 $)[1];
 
-my %is_installed = map {
-    $_, (eval("require $_") || 0);
-} qw (Data::Dumper Devel::Symdump CGI B Apache::Peek Apache::Symbol);
+my %is_installed = ();
+
+{
+    local $SIG{__DIE__};
+    %is_installed = map {
+	$_, (eval("require $_") || 0);
+    } qw (Data::Dumper Devel::Symdump CGI B Apache::Peek Apache::Symbol);
+}
 
 my $CPAN_base = "http://www.perl.com/CPAN/modules/by-module";
 
@@ -22,7 +27,7 @@ my(%status) = (
    hooks => "Enabled mod_perl Hooks",
 );
 
-if($Apache::ReadConfig) {
+if($Apache::Server::SaveConfig) {
     $status{"section_config"} = "Perl Section Configuration";
 }
 
@@ -105,6 +110,7 @@ sub status_section_config {
 sub status_hooks {
     my($r,$q) = @_;
     require mod_perl;
+    require mod_perl_hooks;
     my @retval = qw(<table>);
     my @list = mod_perl::hooks();
     for my $hook (sort @list) {
@@ -127,6 +133,7 @@ sub status_inc {
     "</tr>";
 
     foreach $file (sort keys %INC) {
+	local $^W = 0;
 	next if $file =~ m:^/:;
 	next unless $file =~ m:\.pm:;
 	next unless $INC{$file}; #e.g. fake Apache/TieHandle.pm
@@ -395,7 +402,8 @@ sub as_HTML {
 		    push @line, $_;
 		}
 	    }
-	    elsif($do_dump and $can_dump{$type}) {
+	    elsif($do_dump and $can_dump{$type} and 
+		  $is_installed{"Data::Dumper"}) {
 		next if /_</;
 		push @line, qq(<a href="$uri/$_/$dtype?data_dump">$_</a>);
 	    }
@@ -444,11 +452,13 @@ Other modules can "plugin" a menu item like so:
         my($r,$q) = @_; #request and CGI objects
         my(@strings);
         push @strings,  "blobs of html";
-        return \@s;     #return an array ref
+        return \@strings;     #return an array ref
     }
  ) if Apache->module("Apache::Status"); #only if Apache::Status is loaded
 
-
+B<WARNING>: Apache::Status must be loaded before these modules via the 
+PerlModule or PerlRequire directives.
+  
 =head1 OPTIONS
 
 =over 4
